=======
Credits
=======

Development Lead
----------------

* Daniel C. Moura <daniel.c.moura@gmail.com>

Contributors
------------

* Diogo Recharte <diogorecharte@gmail.com>
* Ricardo Chaves <github.com/ricardocchaves>
* Yash Bonde <github.com/yashbonde>
